% Intrinsic and Extrinsic Camera Parameters
%
% This script file can be directly excecuted under Matlab to recover the camera intrinsic and extrinsic parameters.
% IMPORTANT: This file contains neither the structure of the calibration objects nor the image coordinates of the calibration points.
%            All those complementary variables are saved in the complete matlab data file Calib_Results.mat.
% For more information regarding the calibration model visit http://www.vision.caltech.edu/bouguetj/calib_doc/


%-- Focal length:
fc = [ 1123.706951117357448 ; 1127.053650927749459 ];

%-- Principal point:
cc = [ 493.560015779452272 ; 492.966503336302310 ];

%-- Skew coefficient:
alpha_c = 0.000000000000000;

%-- Distortion coefficients:
kc = [ -0.129651858328045 ; 0.181708791768012 ; -0.001244011372941 ; 0.001550525270695 ; 0.000000000000000 ];

%-- Focal length uncertainty:
fc_error = [ 3.046360766853609 ; 3.003001789550142 ];

%-- Principal point uncertainty:
cc_error = [ 4.650632542427188 ; 3.548412076299986 ];

%-- Skew coefficient uncertainty:
alpha_c_error = 0.000000000000000;

%-- Distortion coefficients uncertainty:
kc_error = [ 0.014905884388938 ; 0.156211789681480 ; 0.000787168264076 ; 0.000977879454261 ; 0.000000000000000 ];

%-- Image size:
nx = 1004;
ny = 1004;


%-- Various other variables (may be ignored if you do not use the Matlab Calibration Toolbox):
%-- Those variables are used to control which intrinsic parameters should be optimized

n_ima = 171;						% Number of calibration images
est_fc = [ 1 ; 1 ];					% Estimation indicator of the two focal variables
est_aspect_ratio = 1;				% Estimation indicator of the aspect ratio fc(2)/fc(1)
center_optim = 1;					% Estimation indicator of the principal point
est_alpha = 0;						% Estimation indicator of the skew coefficient
est_dist = [ 1 ; 1 ; 1 ; 1 ; 0 ];	% Estimation indicator of the distortion coefficients


%-- Extrinsic parameters:
%-- The rotation (omc_kk) and the translation (Tc_kk) vectors for every calibration image and their uncertainties

%-- Image #1:
omc_1 = [ -2.107072e+00 ; -2.267942e+00 ; -1.856467e-02 ];
Tc_1  = [ -1.850644e+02 ; -1.865505e+02 ; 1.259969e+03 ];
omc_error_1 = [ 3.828768e-03 ; 4.219020e-03 ; 8.665051e-03 ];
Tc_error_1  = [ 5.238329e+00 ; 3.989977e+00 ; 3.771869e+00 ];

%-- Image #2:
omc_2 = [ NaN ; NaN ; NaN ];
Tc_2  = [ NaN ; NaN ; NaN ];
omc_error_2 = [ NaN ; NaN ; NaN ];
Tc_error_2  = [ NaN ; NaN ; NaN ];

%-- Image #3:
omc_3 = [ NaN ; NaN ; NaN ];
Tc_3  = [ NaN ; NaN ; NaN ];
omc_error_3 = [ NaN ; NaN ; NaN ];
Tc_error_3  = [ NaN ; NaN ; NaN ];

%-- Image #4:
omc_4 = [ NaN ; NaN ; NaN ];
Tc_4  = [ NaN ; NaN ; NaN ];
omc_error_4 = [ NaN ; NaN ; NaN ];
Tc_error_4  = [ NaN ; NaN ; NaN ];

%-- Image #5:
omc_5 = [ NaN ; NaN ; NaN ];
Tc_5  = [ NaN ; NaN ; NaN ];
omc_error_5 = [ NaN ; NaN ; NaN ];
Tc_error_5  = [ NaN ; NaN ; NaN ];

%-- Image #6:
omc_6 = [ NaN ; NaN ; NaN ];
Tc_6  = [ NaN ; NaN ; NaN ];
omc_error_6 = [ NaN ; NaN ; NaN ];
Tc_error_6  = [ NaN ; NaN ; NaN ];

%-- Image #7:
omc_7 = [ NaN ; NaN ; NaN ];
Tc_7  = [ NaN ; NaN ; NaN ];
omc_error_7 = [ NaN ; NaN ; NaN ];
Tc_error_7  = [ NaN ; NaN ; NaN ];

%-- Image #8:
omc_8 = [ NaN ; NaN ; NaN ];
Tc_8  = [ NaN ; NaN ; NaN ];
omc_error_8 = [ NaN ; NaN ; NaN ];
Tc_error_8  = [ NaN ; NaN ; NaN ];

%-- Image #9:
omc_9 = [ NaN ; NaN ; NaN ];
Tc_9  = [ NaN ; NaN ; NaN ];
omc_error_9 = [ NaN ; NaN ; NaN ];
Tc_error_9  = [ NaN ; NaN ; NaN ];

%-- Image #10:
omc_10 = [ NaN ; NaN ; NaN ];
Tc_10  = [ NaN ; NaN ; NaN ];
omc_error_10 = [ NaN ; NaN ; NaN ];
Tc_error_10  = [ NaN ; NaN ; NaN ];

%-- Image #11:
omc_11 = [ -2.106924e+00 ; -2.263898e+00 ; -2.236022e-02 ];
Tc_11  = [ -1.856873e+02 ; -1.857682e+02 ; 1.259316e+03 ];
omc_error_11 = [ 3.818388e-03 ; 4.211796e-03 ; 8.643688e-03 ];
Tc_error_11  = [ 5.235719e+00 ; 3.988758e+00 ; 3.772661e+00 ];

%-- Image #12:
omc_12 = [ NaN ; NaN ; NaN ];
Tc_12  = [ NaN ; NaN ; NaN ];
omc_error_12 = [ NaN ; NaN ; NaN ];
Tc_error_12  = [ NaN ; NaN ; NaN ];

%-- Image #13:
omc_13 = [ NaN ; NaN ; NaN ];
Tc_13  = [ NaN ; NaN ; NaN ];
omc_error_13 = [ NaN ; NaN ; NaN ];
Tc_error_13  = [ NaN ; NaN ; NaN ];

%-- Image #14:
omc_14 = [ NaN ; NaN ; NaN ];
Tc_14  = [ NaN ; NaN ; NaN ];
omc_error_14 = [ NaN ; NaN ; NaN ];
Tc_error_14  = [ NaN ; NaN ; NaN ];

%-- Image #15:
omc_15 = [ NaN ; NaN ; NaN ];
Tc_15  = [ NaN ; NaN ; NaN ];
omc_error_15 = [ NaN ; NaN ; NaN ];
Tc_error_15  = [ NaN ; NaN ; NaN ];

%-- Image #16:
omc_16 = [ NaN ; NaN ; NaN ];
Tc_16  = [ NaN ; NaN ; NaN ];
omc_error_16 = [ NaN ; NaN ; NaN ];
Tc_error_16  = [ NaN ; NaN ; NaN ];

%-- Image #17:
omc_17 = [ NaN ; NaN ; NaN ];
Tc_17  = [ NaN ; NaN ; NaN ];
omc_error_17 = [ NaN ; NaN ; NaN ];
Tc_error_17  = [ NaN ; NaN ; NaN ];

%-- Image #18:
omc_18 = [ NaN ; NaN ; NaN ];
Tc_18  = [ NaN ; NaN ; NaN ];
omc_error_18 = [ NaN ; NaN ; NaN ];
Tc_error_18  = [ NaN ; NaN ; NaN ];

%-- Image #19:
omc_19 = [ NaN ; NaN ; NaN ];
Tc_19  = [ NaN ; NaN ; NaN ];
omc_error_19 = [ NaN ; NaN ; NaN ];
Tc_error_19  = [ NaN ; NaN ; NaN ];

%-- Image #20:
omc_20 = [ NaN ; NaN ; NaN ];
Tc_20  = [ NaN ; NaN ; NaN ];
omc_error_20 = [ NaN ; NaN ; NaN ];
Tc_error_20  = [ NaN ; NaN ; NaN ];

%-- Image #21:
omc_21 = [ -2.112480e+00 ; -2.256920e+00 ; -1.239328e-02 ];
Tc_21  = [ -1.884032e+02 ; -1.857202e+02 ; 1.262560e+03 ];
omc_error_21 = [ 3.841998e-03 ; 4.200691e-03 ; 8.670729e-03 ];
Tc_error_21  = [ 5.248222e+00 ; 3.997860e+00 ; 3.779026e+00 ];

%-- Image #22:
omc_22 = [ NaN ; NaN ; NaN ];
Tc_22  = [ NaN ; NaN ; NaN ];
omc_error_22 = [ NaN ; NaN ; NaN ];
Tc_error_22  = [ NaN ; NaN ; NaN ];

%-- Image #23:
omc_23 = [ NaN ; NaN ; NaN ];
Tc_23  = [ NaN ; NaN ; NaN ];
omc_error_23 = [ NaN ; NaN ; NaN ];
Tc_error_23  = [ NaN ; NaN ; NaN ];

%-- Image #24:
omc_24 = [ NaN ; NaN ; NaN ];
Tc_24  = [ NaN ; NaN ; NaN ];
omc_error_24 = [ NaN ; NaN ; NaN ];
Tc_error_24  = [ NaN ; NaN ; NaN ];

%-- Image #25:
omc_25 = [ NaN ; NaN ; NaN ];
Tc_25  = [ NaN ; NaN ; NaN ];
omc_error_25 = [ NaN ; NaN ; NaN ];
Tc_error_25  = [ NaN ; NaN ; NaN ];

%-- Image #26:
omc_26 = [ NaN ; NaN ; NaN ];
Tc_26  = [ NaN ; NaN ; NaN ];
omc_error_26 = [ NaN ; NaN ; NaN ];
Tc_error_26  = [ NaN ; NaN ; NaN ];

%-- Image #27:
omc_27 = [ NaN ; NaN ; NaN ];
Tc_27  = [ NaN ; NaN ; NaN ];
omc_error_27 = [ NaN ; NaN ; NaN ];
Tc_error_27  = [ NaN ; NaN ; NaN ];

%-- Image #28:
omc_28 = [ NaN ; NaN ; NaN ];
Tc_28  = [ NaN ; NaN ; NaN ];
omc_error_28 = [ NaN ; NaN ; NaN ];
Tc_error_28  = [ NaN ; NaN ; NaN ];

%-- Image #29:
omc_29 = [ NaN ; NaN ; NaN ];
Tc_29  = [ NaN ; NaN ; NaN ];
omc_error_29 = [ NaN ; NaN ; NaN ];
Tc_error_29  = [ NaN ; NaN ; NaN ];

%-- Image #30:
omc_30 = [ NaN ; NaN ; NaN ];
Tc_30  = [ NaN ; NaN ; NaN ];
omc_error_30 = [ NaN ; NaN ; NaN ];
Tc_error_30  = [ NaN ; NaN ; NaN ];

%-- Image #31:
omc_31 = [ -2.108102e+00 ; -2.241644e+00 ; -7.584375e-03 ];
Tc_31  = [ -1.927389e+02 ; -1.778473e+02 ; 1.279133e+03 ];
omc_error_31 = [ 3.846187e-03 ; 4.229841e-03 ; 8.694559e-03 ];
Tc_error_31  = [ 5.313576e+00 ; 4.050014e+00 ; 3.826395e+00 ];

%-- Image #32:
omc_32 = [ NaN ; NaN ; NaN ];
Tc_32  = [ NaN ; NaN ; NaN ];
omc_error_32 = [ NaN ; NaN ; NaN ];
Tc_error_32  = [ NaN ; NaN ; NaN ];

%-- Image #33:
omc_33 = [ NaN ; NaN ; NaN ];
Tc_33  = [ NaN ; NaN ; NaN ];
omc_error_33 = [ NaN ; NaN ; NaN ];
Tc_error_33  = [ NaN ; NaN ; NaN ];

%-- Image #34:
omc_34 = [ NaN ; NaN ; NaN ];
Tc_34  = [ NaN ; NaN ; NaN ];
omc_error_34 = [ NaN ; NaN ; NaN ];
Tc_error_34  = [ NaN ; NaN ; NaN ];

%-- Image #35:
omc_35 = [ NaN ; NaN ; NaN ];
Tc_35  = [ NaN ; NaN ; NaN ];
omc_error_35 = [ NaN ; NaN ; NaN ];
Tc_error_35  = [ NaN ; NaN ; NaN ];

%-- Image #36:
omc_36 = [ NaN ; NaN ; NaN ];
Tc_36  = [ NaN ; NaN ; NaN ];
omc_error_36 = [ NaN ; NaN ; NaN ];
Tc_error_36  = [ NaN ; NaN ; NaN ];

%-- Image #37:
omc_37 = [ NaN ; NaN ; NaN ];
Tc_37  = [ NaN ; NaN ; NaN ];
omc_error_37 = [ NaN ; NaN ; NaN ];
Tc_error_37  = [ NaN ; NaN ; NaN ];

%-- Image #38:
omc_38 = [ NaN ; NaN ; NaN ];
Tc_38  = [ NaN ; NaN ; NaN ];
omc_error_38 = [ NaN ; NaN ; NaN ];
Tc_error_38  = [ NaN ; NaN ; NaN ];

%-- Image #39:
omc_39 = [ NaN ; NaN ; NaN ];
Tc_39  = [ NaN ; NaN ; NaN ];
omc_error_39 = [ NaN ; NaN ; NaN ];
Tc_error_39  = [ NaN ; NaN ; NaN ];

%-- Image #40:
omc_40 = [ NaN ; NaN ; NaN ];
Tc_40  = [ NaN ; NaN ; NaN ];
omc_error_40 = [ NaN ; NaN ; NaN ];
Tc_error_40  = [ NaN ; NaN ; NaN ];

%-- Image #41:
omc_41 = [ -2.149984e+00 ; -2.281943e+00 ; 1.097439e-01 ];
Tc_41  = [ -1.866150e+02 ; -1.779456e+02 ; 1.273852e+03 ];
omc_error_41 = [ 3.788226e-03 ; 3.883128e-03 ; 8.384876e-03 ];
Tc_error_41  = [ 5.284128e+00 ; 4.012189e+00 ; 3.698932e+00 ];

%-- Image #42:
omc_42 = [ NaN ; NaN ; NaN ];
Tc_42  = [ NaN ; NaN ; NaN ];
omc_error_42 = [ NaN ; NaN ; NaN ];
Tc_error_42  = [ NaN ; NaN ; NaN ];

%-- Image #43:
omc_43 = [ NaN ; NaN ; NaN ];
Tc_43  = [ NaN ; NaN ; NaN ];
omc_error_43 = [ NaN ; NaN ; NaN ];
Tc_error_43  = [ NaN ; NaN ; NaN ];

%-- Image #44:
omc_44 = [ NaN ; NaN ; NaN ];
Tc_44  = [ NaN ; NaN ; NaN ];
omc_error_44 = [ NaN ; NaN ; NaN ];
Tc_error_44  = [ NaN ; NaN ; NaN ];

%-- Image #45:
omc_45 = [ NaN ; NaN ; NaN ];
Tc_45  = [ NaN ; NaN ; NaN ];
omc_error_45 = [ NaN ; NaN ; NaN ];
Tc_error_45  = [ NaN ; NaN ; NaN ];

%-- Image #46:
omc_46 = [ NaN ; NaN ; NaN ];
Tc_46  = [ NaN ; NaN ; NaN ];
omc_error_46 = [ NaN ; NaN ; NaN ];
Tc_error_46  = [ NaN ; NaN ; NaN ];

%-- Image #47:
omc_47 = [ NaN ; NaN ; NaN ];
Tc_47  = [ NaN ; NaN ; NaN ];
omc_error_47 = [ NaN ; NaN ; NaN ];
Tc_error_47  = [ NaN ; NaN ; NaN ];

%-- Image #48:
omc_48 = [ NaN ; NaN ; NaN ];
Tc_48  = [ NaN ; NaN ; NaN ];
omc_error_48 = [ NaN ; NaN ; NaN ];
Tc_error_48  = [ NaN ; NaN ; NaN ];

%-- Image #49:
omc_49 = [ NaN ; NaN ; NaN ];
Tc_49  = [ NaN ; NaN ; NaN ];
omc_error_49 = [ NaN ; NaN ; NaN ];
Tc_error_49  = [ NaN ; NaN ; NaN ];

%-- Image #50:
omc_50 = [ NaN ; NaN ; NaN ];
Tc_50  = [ NaN ; NaN ; NaN ];
omc_error_50 = [ NaN ; NaN ; NaN ];
Tc_error_50  = [ NaN ; NaN ; NaN ];

%-- Image #51:
omc_51 = [ -2.091406e+00 ; -2.204856e+00 ; 2.307117e-02 ];
Tc_51  = [ -1.789215e+02 ; -2.051781e+02 ; 1.054526e+03 ];
omc_error_51 = [ 3.021953e-03 ; 3.250310e-03 ; 6.742990e-03 ];
Tc_error_51  = [ 4.392359e+00 ; 3.342695e+00 ; 3.127052e+00 ];

%-- Image #52:
omc_52 = [ NaN ; NaN ; NaN ];
Tc_52  = [ NaN ; NaN ; NaN ];
omc_error_52 = [ NaN ; NaN ; NaN ];
Tc_error_52  = [ NaN ; NaN ; NaN ];

%-- Image #53:
omc_53 = [ NaN ; NaN ; NaN ];
Tc_53  = [ NaN ; NaN ; NaN ];
omc_error_53 = [ NaN ; NaN ; NaN ];
Tc_error_53  = [ NaN ; NaN ; NaN ];

%-- Image #54:
omc_54 = [ NaN ; NaN ; NaN ];
Tc_54  = [ NaN ; NaN ; NaN ];
omc_error_54 = [ NaN ; NaN ; NaN ];
Tc_error_54  = [ NaN ; NaN ; NaN ];

%-- Image #55:
omc_55 = [ NaN ; NaN ; NaN ];
Tc_55  = [ NaN ; NaN ; NaN ];
omc_error_55 = [ NaN ; NaN ; NaN ];
Tc_error_55  = [ NaN ; NaN ; NaN ];

%-- Image #56:
omc_56 = [ NaN ; NaN ; NaN ];
Tc_56  = [ NaN ; NaN ; NaN ];
omc_error_56 = [ NaN ; NaN ; NaN ];
Tc_error_56  = [ NaN ; NaN ; NaN ];

%-- Image #57:
omc_57 = [ NaN ; NaN ; NaN ];
Tc_57  = [ NaN ; NaN ; NaN ];
omc_error_57 = [ NaN ; NaN ; NaN ];
Tc_error_57  = [ NaN ; NaN ; NaN ];

%-- Image #58:
omc_58 = [ NaN ; NaN ; NaN ];
Tc_58  = [ NaN ; NaN ; NaN ];
omc_error_58 = [ NaN ; NaN ; NaN ];
Tc_error_58  = [ NaN ; NaN ; NaN ];

%-- Image #59:
omc_59 = [ NaN ; NaN ; NaN ];
Tc_59  = [ NaN ; NaN ; NaN ];
omc_error_59 = [ NaN ; NaN ; NaN ];
Tc_error_59  = [ NaN ; NaN ; NaN ];

%-- Image #60:
omc_60 = [ NaN ; NaN ; NaN ];
Tc_60  = [ NaN ; NaN ; NaN ];
omc_error_60 = [ NaN ; NaN ; NaN ];
Tc_error_60  = [ NaN ; NaN ; NaN ];

%-- Image #61:
omc_61 = [ -1.989675e+00 ; -2.226720e+00 ; -6.572914e-02 ];
Tc_61  = [ -1.681701e+02 ; -2.126669e+02 ; 9.519223e+02 ];
omc_error_61 = [ 2.576324e-03 ; 3.147321e-03 ; 5.903033e-03 ];
Tc_error_61  = [ 3.977303e+00 ; 3.036386e+00 ; 2.847141e+00 ];

%-- Image #62:
omc_62 = [ NaN ; NaN ; NaN ];
Tc_62  = [ NaN ; NaN ; NaN ];
omc_error_62 = [ NaN ; NaN ; NaN ];
Tc_error_62  = [ NaN ; NaN ; NaN ];

%-- Image #63:
omc_63 = [ NaN ; NaN ; NaN ];
Tc_63  = [ NaN ; NaN ; NaN ];
omc_error_63 = [ NaN ; NaN ; NaN ];
Tc_error_63  = [ NaN ; NaN ; NaN ];

%-- Image #64:
omc_64 = [ NaN ; NaN ; NaN ];
Tc_64  = [ NaN ; NaN ; NaN ];
omc_error_64 = [ NaN ; NaN ; NaN ];
Tc_error_64  = [ NaN ; NaN ; NaN ];

%-- Image #65:
omc_65 = [ NaN ; NaN ; NaN ];
Tc_65  = [ NaN ; NaN ; NaN ];
omc_error_65 = [ NaN ; NaN ; NaN ];
Tc_error_65  = [ NaN ; NaN ; NaN ];

%-- Image #66:
omc_66 = [ NaN ; NaN ; NaN ];
Tc_66  = [ NaN ; NaN ; NaN ];
omc_error_66 = [ NaN ; NaN ; NaN ];
Tc_error_66  = [ NaN ; NaN ; NaN ];

%-- Image #67:
omc_67 = [ NaN ; NaN ; NaN ];
Tc_67  = [ NaN ; NaN ; NaN ];
omc_error_67 = [ NaN ; NaN ; NaN ];
Tc_error_67  = [ NaN ; NaN ; NaN ];

%-- Image #68:
omc_68 = [ NaN ; NaN ; NaN ];
Tc_68  = [ NaN ; NaN ; NaN ];
omc_error_68 = [ NaN ; NaN ; NaN ];
Tc_error_68  = [ NaN ; NaN ; NaN ];

%-- Image #69:
omc_69 = [ NaN ; NaN ; NaN ];
Tc_69  = [ NaN ; NaN ; NaN ];
omc_error_69 = [ NaN ; NaN ; NaN ];
Tc_error_69  = [ NaN ; NaN ; NaN ];

%-- Image #70:
omc_70 = [ NaN ; NaN ; NaN ];
Tc_70  = [ NaN ; NaN ; NaN ];
omc_error_70 = [ NaN ; NaN ; NaN ];
Tc_error_70  = [ NaN ; NaN ; NaN ];

%-- Image #71:
omc_71 = [ -1.985049e+00 ; -2.226315e+00 ; -9.919252e-02 ];
Tc_71  = [ -1.682466e+02 ; -1.953904e+02 ; 1.044692e+03 ];
omc_error_71 = [ 2.658153e-03 ; 3.359983e-03 ; 6.288809e-03 ];
Tc_error_71  = [ 4.353857e+00 ; 3.324920e+00 ; 3.110085e+00 ];

%-- Image #72:
omc_72 = [ NaN ; NaN ; NaN ];
Tc_72  = [ NaN ; NaN ; NaN ];
omc_error_72 = [ NaN ; NaN ; NaN ];

Tc_error_72  = [ NaN ; NaN ; NaN ];

%-- Image #73:
omc_73 = [ NaN ; NaN ; NaN ];
Tc_73  = [ NaN ; NaN ; NaN ];
omc_error_73 = [ NaN ; NaN ; NaN ];
Tc_error_73  = [ NaN ; NaN ; NaN ];

%-- Image #74:
omc_74 = [ NaN ; NaN ; NaN ];
Tc_74  = [ NaN ; NaN ; NaN ];
omc_error_74 = [ NaN ; NaN ; NaN ];
Tc_error_74  = [ NaN ; NaN ; NaN ];

%-- Image #75:
omc_75 = [ NaN ; NaN ; NaN ];
Tc_75  = [ NaN ; NaN ; NaN ];
omc_error_75 = [ NaN ; NaN ; NaN ];
Tc_error_75  = [ NaN ; NaN ; NaN ];

%-- Image #76:
omc_76 = [ NaN ; NaN ; NaN ];
Tc_76  = [ NaN ; NaN ; NaN ];
omc_error_76 = [ NaN ; NaN ; NaN ];
Tc_error_76  = [ NaN ; NaN ; NaN ];

%-- Image #77:
omc_77 = [ NaN ; NaN ; NaN ];
Tc_77  = [ NaN ; NaN ; NaN ];
omc_error_77 = [ NaN ; NaN ; NaN ];
Tc_error_77  = [ NaN ; NaN ; NaN ];

%-- Image #78:
omc_78 = [ NaN ; NaN ; NaN ];
Tc_78  = [ NaN ; NaN ; NaN ];
omc_error_78 = [ NaN ; NaN ; NaN ];
Tc_error_78  = [ NaN ; NaN ; NaN ];

%-- Image #79:
omc_79 = [ NaN ; NaN ; NaN ];
Tc_79  = [ NaN ; NaN ; NaN ];
omc_error_79 = [ NaN ; NaN ; NaN ];
Tc_error_79  = [ NaN ; NaN ; NaN ];

%-- Image #80:
omc_80 = [ NaN ; NaN ; NaN ];
Tc_80  = [ NaN ; NaN ; NaN ];
omc_error_80 = [ NaN ; NaN ; NaN ];
Tc_error_80  = [ NaN ; NaN ; NaN ];

%-- Image #81:
omc_81 = [ -2.032646e+00 ; -2.260322e+00 ; -7.756364e-02 ];
Tc_81  = [ -1.735659e+02 ; -1.890529e+02 ; 1.231714e+03 ];
omc_error_81 = [ 3.380479e-03 ; 4.044929e-03 ; 7.838852e-03 ];
Tc_error_81  = [ 5.123361e+00 ; 3.909690e+00 ; 3.687297e+00 ];

%-- Image #82:
omc_82 = [ NaN ; NaN ; NaN ];
Tc_82  = [ NaN ; NaN ; NaN ];
omc_error_82 = [ NaN ; NaN ; NaN ];
Tc_error_82  = [ NaN ; NaN ; NaN ];

%-- Image #83:
omc_83 = [ NaN ; NaN ; NaN ];
Tc_83  = [ NaN ; NaN ; NaN ];
omc_error_83 = [ NaN ; NaN ; NaN ];
Tc_error_83  = [ NaN ; NaN ; NaN ];

%-- Image #84:
omc_84 = [ NaN ; NaN ; NaN ];
Tc_84  = [ NaN ; NaN ; NaN ];
omc_error_84 = [ NaN ; NaN ; NaN ];
Tc_error_84  = [ NaN ; NaN ; NaN ];

%-- Image #85:
omc_85 = [ NaN ; NaN ; NaN ];
Tc_85  = [ NaN ; NaN ; NaN ];
omc_error_85 = [ NaN ; NaN ; NaN ];
Tc_error_85  = [ NaN ; NaN ; NaN ];

%-- Image #86:
omc_86 = [ NaN ; NaN ; NaN ];
Tc_86  = [ NaN ; NaN ; NaN ];
omc_error_86 = [ NaN ; NaN ; NaN ];
Tc_error_86  = [ NaN ; NaN ; NaN ];

%-- Image #87:
omc_87 = [ NaN ; NaN ; NaN ];
Tc_87  = [ NaN ; NaN ; NaN ];
omc_error_87 = [ NaN ; NaN ; NaN ];
Tc_error_87  = [ NaN ; NaN ; NaN ];

%-- Image #88:
omc_88 = [ NaN ; NaN ; NaN ];
Tc_88  = [ NaN ; NaN ; NaN ];
omc_error_88 = [ NaN ; NaN ; NaN ];
Tc_error_88  = [ NaN ; NaN ; NaN ];

%-- Image #89:
omc_89 = [ NaN ; NaN ; NaN ];
Tc_89  = [ NaN ; NaN ; NaN ];
omc_error_89 = [ NaN ; NaN ; NaN ];
Tc_error_89  = [ NaN ; NaN ; NaN ];

%-- Image #90:
omc_90 = [ NaN ; NaN ; NaN ];
Tc_90  = [ NaN ; NaN ; NaN ];
omc_error_90 = [ NaN ; NaN ; NaN ];
Tc_error_90  = [ NaN ; NaN ; NaN ];

%-- Image #91:
omc_91 = [ 2.112603e+00 ; 2.231515e+00 ; 1.633816e-01 ];
Tc_91  = [ -1.765841e+02 ; -1.925540e+02 ; 1.304273e+03 ];
omc_error_91 = [ 3.619957e-03 ; 3.806680e-03 ; 7.908318e-03 ];
Tc_error_91  = [ 5.433905e+00 ; 4.125336e+00 ; 3.895570e+00 ];

%-- Image #92:
omc_92 = [ NaN ; NaN ; NaN ];
Tc_92  = [ NaN ; NaN ; NaN ];
omc_error_92 = [ NaN ; NaN ; NaN ];
Tc_error_92  = [ NaN ; NaN ; NaN ];

%-- Image #93:
omc_93 = [ NaN ; NaN ; NaN ];
Tc_93  = [ NaN ; NaN ; NaN ];
omc_error_93 = [ NaN ; NaN ; NaN ];
Tc_error_93  = [ NaN ; NaN ; NaN ];

%-- Image #94:
omc_94 = [ NaN ; NaN ; NaN ];
Tc_94  = [ NaN ; NaN ; NaN ];
omc_error_94 = [ NaN ; NaN ; NaN ];
Tc_error_94  = [ NaN ; NaN ; NaN ];

%-- Image #95:
omc_95 = [ NaN ; NaN ; NaN ];
Tc_95  = [ NaN ; NaN ; NaN ];
omc_error_95 = [ NaN ; NaN ; NaN ];
Tc_error_95  = [ NaN ; NaN ; NaN ];

%-- Image #96:
omc_96 = [ NaN ; NaN ; NaN ];
Tc_96  = [ NaN ; NaN ; NaN ];
omc_error_96 = [ NaN ; NaN ; NaN ];
Tc_error_96  = [ NaN ; NaN ; NaN ];

%-- Image #97:
omc_97 = [ NaN ; NaN ; NaN ];
Tc_97  = [ NaN ; NaN ; NaN ];
omc_error_97 = [ NaN ; NaN ; NaN ];
Tc_error_97  = [ NaN ; NaN ; NaN ];

%-- Image #98:
omc_98 = [ NaN ; NaN ; NaN ];
Tc_98  = [ NaN ; NaN ; NaN ];
omc_error_98 = [ NaN ; NaN ; NaN ];
Tc_error_98  = [ NaN ; NaN ; NaN ];

%-- Image #99:
omc_99 = [ NaN ; NaN ; NaN ];
Tc_99  = [ NaN ; NaN ; NaN ];
omc_error_99 = [ NaN ; NaN ; NaN ];
Tc_error_99  = [ NaN ; NaN ; NaN ];

%-- Image #100:
omc_100 = [ NaN ; NaN ; NaN ];
Tc_100  = [ NaN ; NaN ; NaN ];
omc_error_100 = [ NaN ; NaN ; NaN ];
Tc_error_100  = [ NaN ; NaN ; NaN ];

%-- Image #101:
omc_101 = [ 1.858300e+00 ; 1.967917e+00 ; 7.948498e-01 ];
Tc_101  = [ -1.491038e+02 ; -1.971212e+02 ; 1.118502e+03 ];
omc_error_101 = [ 3.498919e-03 ; 2.793513e-03 ; 5.108268e-03 ];
Tc_error_101  = [ 4.671269e+00 ; 3.536283e+00 ; 3.524495e+00 ];

%-- Image #102:
omc_102 = [ NaN ; NaN ; NaN ];
Tc_102  = [ NaN ; NaN ; NaN ];
omc_error_102 = [ NaN ; NaN ; NaN ];
Tc_error_102  = [ NaN ; NaN ; NaN ];

%-- Image #103:
omc_103 = [ NaN ; NaN ; NaN ];
Tc_103  = [ NaN ; NaN ; NaN ];
omc_error_103 = [ NaN ; NaN ; NaN ];
Tc_error_103  = [ NaN ; NaN ; NaN ];

%-- Image #104:
omc_104 = [ NaN ; NaN ; NaN ];
Tc_104  = [ NaN ; NaN ; NaN ];
omc_error_104 = [ NaN ; NaN ; NaN ];
Tc_error_104  = [ NaN ; NaN ; NaN ];

%-- Image #105:
omc_105 = [ NaN ; NaN ; NaN ];
Tc_105  = [ NaN ; NaN ; NaN ];
omc_error_105 = [ NaN ; NaN ; NaN ];
Tc_error_105  = [ NaN ; NaN ; NaN ];

%-- Image #106:
omc_106 = [ NaN ; NaN ; NaN ];
Tc_106  = [ NaN ; NaN ; NaN ];
omc_error_106 = [ NaN ; NaN ; NaN ];
Tc_error_106  = [ NaN ; NaN ; NaN ];

%-- Image #107:
omc_107 = [ NaN ; NaN ; NaN ];
Tc_107  = [ NaN ; NaN ; NaN ];
omc_error_107 = [ NaN ; NaN ; NaN ];
Tc_error_107  = [ NaN ; NaN ; NaN ];

%-- Image #108:
omc_108 = [ NaN ; NaN ; NaN ];
Tc_108  = [ NaN ; NaN ; NaN ];
omc_error_108 = [ NaN ; NaN ; NaN ];
Tc_error_108  = [ NaN ; NaN ; NaN ];

%-- Image #109:
omc_109 = [ NaN ; NaN ; NaN ];
Tc_109  = [ NaN ; NaN ; NaN ];
omc_error_109 = [ NaN ; NaN ; NaN ];
Tc_error_109  = [ NaN ; NaN ; NaN ];

%-- Image #110:
omc_110 = [ NaN ; NaN ; NaN ];
Tc_110  = [ NaN ; NaN ; NaN ];
omc_error_110 = [ NaN ; NaN ; NaN ];
Tc_error_110  = [ NaN ; NaN ; NaN ];

%-- Image #111:
omc_111 = [ 1.644461e+00 ; 1.584019e+00 ; 9.899420e-01 ];
Tc_111  = [ -1.399899e+02 ; -1.790249e+02 ; 1.029938e+03 ];
omc_error_111 = [ 3.588638e-03 ; 2.991910e-03 ; 4.247878e-03 ];
Tc_error_111  = [ 4.304145e+00 ; 3.256084e+00 ; 3.351648e+00 ];

%-- Image #112:
omc_112 = [ NaN ; NaN ; NaN ];
Tc_112  = [ NaN ; NaN ; NaN ];
omc_error_112 = [ NaN ; NaN ; NaN ];
Tc_error_112  = [ NaN ; NaN ; NaN ];

%-- Image #113:
omc_113 = [ NaN ; NaN ; NaN ];
Tc_113  = [ NaN ; NaN ; NaN ];
omc_error_113 = [ NaN ; NaN ; NaN ];
Tc_error_113  = [ NaN ; NaN ; NaN ];

%-- Image #114:
omc_114 = [ NaN ; NaN ; NaN ];
Tc_114  = [ NaN ; NaN ; NaN ];
omc_error_114 = [ NaN ; NaN ; NaN ];
Tc_error_114  = [ NaN ; NaN ; NaN ];

%-- Image #115:
omc_115 = [ NaN ; NaN ; NaN ];
Tc_115  = [ NaN ; NaN ; NaN ];
omc_error_115 = [ NaN ; NaN ; NaN ];
Tc_error_115  = [ NaN ; NaN ; NaN ];

%-- Image #116:
omc_116 = [ NaN ; NaN ; NaN ];
Tc_116  = [ NaN ; NaN ; NaN ];
omc_error_116 = [ NaN ; NaN ; NaN ];
Tc_error_116  = [ NaN ; NaN ; NaN ];

%-- Image #117:
omc_117 = [ NaN ; NaN ; NaN ];
Tc_117  = [ NaN ; NaN ; NaN ];
omc_error_117 = [ NaN ; NaN ; NaN ];
Tc_error_117  = [ NaN ; NaN ; NaN ];

%-- Image #118:
omc_118 = [ NaN ; NaN ; NaN ];
Tc_118  = [ NaN ; NaN ; NaN ];
omc_error_118 = [ NaN ; NaN ; NaN ];
Tc_error_118  = [ NaN ; NaN ; NaN ];

%-- Image #119:
omc_119 = [ NaN ; NaN ; NaN ];
Tc_119  = [ NaN ; NaN ; NaN ];
omc_error_119 = [ NaN ; NaN ; NaN ];
Tc_error_119  = [ NaN ; NaN ; NaN ];

%-- Image #120:
omc_120 = [ NaN ; NaN ; NaN ];
Tc_120  = [ NaN ; NaN ; NaN ];
omc_error_120 = [ NaN ; NaN ; NaN ];
Tc_error_120  = [ NaN ; NaN ; NaN ];

%-- Image #121:
omc_121 = [ 1.807376e+00 ; 1.715900e+00 ; 9.416938e-01 ];
Tc_121  = [ -1.637848e+02 ; -1.660900e+02 ; 1.037039e+03 ];
omc_error_121 = [ 3.620408e-03 ; 2.749191e-03 ; 4.684138e-03 ];
Tc_error_121  = [ 4.333972e+00 ; 3.282104e+00 ; 3.367331e+00 ];

%-- Image #122:
omc_122 = [ NaN ; NaN ; NaN ];
Tc_122  = [ NaN ; NaN ; NaN ];
omc_error_122 = [ NaN ; NaN ; NaN ];
Tc_error_122  = [ NaN ; NaN ; NaN ];

%-- Image #123:
omc_123 = [ NaN ; NaN ; NaN ];
Tc_123  = [ NaN ; NaN ; NaN ];
omc_error_123 = [ NaN ; NaN ; NaN ];
Tc_error_123  = [ NaN ; NaN ; NaN ];

%-- Image #124:
omc_124 = [ NaN ; NaN ; NaN ];
Tc_124  = [ NaN ; NaN ; NaN ];
omc_error_124 = [ NaN ; NaN ; NaN ];
Tc_error_124  = [ NaN ; NaN ; NaN ];

%-- Image #125:
omc_125 = [ NaN ; NaN ; NaN ];
Tc_125  = [ NaN ; NaN ; NaN ];
omc_error_125 = [ NaN ; NaN ; NaN ];
Tc_error_125  = [ NaN ; NaN ; NaN ];

%-- Image #126:
omc_126 = [ NaN ; NaN ; NaN ];
Tc_126  = [ NaN ; NaN ; NaN ];
omc_error_126 = [ NaN ; NaN ; NaN ];
Tc_error_126  = [ NaN ; NaN ; NaN ];

%-- Image #127:
omc_127 = [ NaN ; NaN ; NaN ];
Tc_127  = [ NaN ; NaN ; NaN ];
omc_error_127 = [ NaN ; NaN ; NaN ];
Tc_error_127  = [ NaN ; NaN ; NaN ];

%-- Image #128:
omc_128 = [ NaN ; NaN ; NaN ];
Tc_128  = [ NaN ; NaN ; NaN ];
omc_error_128 = [ NaN ; NaN ; NaN ];
Tc_error_128  = [ NaN ; NaN ; NaN ];

%-- Image #129:
omc_129 = [ NaN ; NaN ; NaN ];
Tc_129  = [ NaN ; NaN ; NaN ];
omc_error_129 = [ NaN ; NaN ; NaN ];
Tc_error_129  = [ NaN ; NaN ; NaN ];

%-- Image #130:
omc_130 = [ NaN ; NaN ; NaN ];
Tc_130  = [ NaN ; NaN ; NaN ];
omc_error_130 = [ NaN ; NaN ; NaN ];
Tc_error_130  = [ NaN ; NaN ; NaN ];

%-- Image #131:
omc_131 = [ 2.158819e+00 ; 2.105739e+00 ; 5.329932e-01 ];
Tc_131  = [ -1.973318e+02 ; -1.894144e+02 ; 1.130640e+03 ];
omc_error_131 = [ 3.446902e-03 ; 2.664596e-03 ; 6.125537e-03 ];
Tc_error_131  = [ 4.732348e+00 ; 3.587616e+00 ; 3.489844e+00 ];

%-- Image #132:
omc_132 = [ NaN ; NaN ; NaN ];
Tc_132  = [ NaN ; NaN ; NaN ];
omc_error_132 = [ NaN ; NaN ; NaN ];
Tc_error_132  = [ NaN ; NaN ; NaN ];

%-- Image #133:
omc_133 = [ NaN ; NaN ; NaN ];
Tc_133  = [ NaN ; NaN ; NaN ];
omc_error_133 = [ NaN ; NaN ; NaN ];
Tc_error_133  = [ NaN ; NaN ; NaN ];

%-- Image #134:
omc_134 = [ NaN ; NaN ; NaN ];
Tc_134  = [ NaN ; NaN ; NaN ];
omc_error_134 = [ NaN ; NaN ; NaN ];
Tc_error_134  = [ NaN ; NaN ; NaN ];

%-- Image #135:
omc_135 = [ NaN ; NaN ; NaN ];
Tc_135  = [ NaN ; NaN ; NaN ];
omc_error_135 = [ NaN ; NaN ; NaN ];
Tc_error_135  = [ NaN ; NaN ; NaN ];

%-- Image #136:
omc_136 = [ NaN ; NaN ; NaN ];
Tc_136  = [ NaN ; NaN ; NaN ];
omc_error_136 = [ NaN ; NaN ; NaN ];
Tc_error_136  = [ NaN ; NaN ; NaN ];

%-- Image #137:
omc_137 = [ NaN ; NaN ; NaN ];
Tc_137  = [ NaN ; NaN ; NaN ];
omc_error_137 = [ NaN ; NaN ; NaN ];
Tc_error_137  = [ NaN ; NaN ; NaN ];

%-- Image #138:
omc_138 = [ NaN ; NaN ; NaN ];
Tc_138  = [ NaN ; NaN ; NaN ];
omc_error_138 = [ NaN ; NaN ; NaN ];
Tc_error_138  = [ NaN ; NaN ; NaN ];

%-- Image #139:
omc_139 = [ NaN ; NaN ; NaN ];
Tc_139  = [ NaN ; NaN ; NaN ];
omc_error_139 = [ NaN ; NaN ; NaN ];
Tc_error_139  = [ NaN ; NaN ; NaN ];

%-- Image #140:
omc_140 = [ NaN ; NaN ; NaN ];
Tc_140  = [ NaN ; NaN ; NaN ];
omc_error_140 = [ NaN ; NaN ; NaN ];
Tc_error_140  = [ NaN ; NaN ; NaN ];

%-- Image #141:
omc_141 = [ -2.031226e+00 ; -2.020170e+00 ; 1.814111e-01 ];
Tc_141  = [ -1.848900e+02 ; -2.154839e+02 ; 1.269360e+03 ];
omc_error_141 = [ 3.145817e-03 ; 3.026060e-03 ; 6.233114e-03 ];
Tc_error_141  = [ 5.272433e+00 ; 4.001923e+00 ; 3.521658e+00 ];

%-- Image #142:
omc_142 = [ NaN ; NaN ; NaN ];
Tc_142  = [ NaN ; NaN ; NaN ];
omc_error_142 = [ NaN ; NaN ; NaN ];
Tc_error_142  = [ NaN ; NaN ; NaN ];

%-- Image #143:
omc_143 = [ NaN ; NaN ; NaN ];
Tc_143  = [ NaN ; NaN ; NaN ];
omc_error_143 = [ NaN ; NaN ; NaN ];
Tc_error_143  = [ NaN ; NaN ; NaN ];

%-- Image #144:
omc_144 = [ NaN ; NaN ; NaN ];
Tc_144  = [ NaN ; NaN ; NaN ];
omc_error_144 = [ NaN ; NaN ; NaN ];
Tc_error_144  = [ NaN ; NaN ; NaN ];

%-- Image #145:
omc_145 = [ NaN ; NaN ; NaN ];
Tc_145  = [ NaN ; NaN ; NaN ];
omc_error_145 = [ NaN ; NaN ; NaN ];
Tc_error_145  = [ NaN ; NaN ; NaN ];

%-- Image #146:
omc_146 = [ NaN ; NaN ; NaN ];
Tc_146  = [ NaN ; NaN ; NaN ];
omc_error_146 = [ NaN ; NaN ; NaN ];
Tc_error_146  = [ NaN ; NaN ; NaN ];

%-- Image #147:
omc_147 = [ NaN ; NaN ; NaN ];
Tc_147  = [ NaN ; NaN ; NaN ];
omc_error_147 = [ NaN ; NaN ; NaN ];
Tc_error_147  = [ NaN ; NaN ; NaN ];

%-- Image #148:
omc_148 = [ NaN ; NaN ; NaN ];
Tc_148  = [ NaN ; NaN ; NaN ];
omc_error_148 = [ NaN ; NaN ; NaN ];
Tc_error_148  = [ NaN ; NaN ; NaN ];

%-- Image #149:
omc_149 = [ NaN ; NaN ; NaN ];
Tc_149  = [ NaN ; NaN ; NaN ];
omc_error_149 = [ NaN ; NaN ; NaN ];
Tc_error_149  = [ NaN ; NaN ; NaN ];

%-- Image #150:
omc_150 = [ NaN ; NaN ; NaN ];
Tc_150  = [ NaN ; NaN ; NaN ];
omc_error_150 = [ NaN ; NaN ; NaN ];
Tc_error_150  = [ NaN ; NaN ; NaN ];

%-- Image #151:
omc_151 = [ -1.735544e+00 ; -1.747413e+00 ; 6.967660e-01 ];
Tc_151  = [ -1.209052e+02 ; -2.071749e+02 ; 1.394400e+03 ];
omc_error_151 = [ 3.377914e-03 ; 2.769678e-03 ; 4.698698e-03 ];
Tc_error_151  = [ 5.792537e+00 ; 4.382478e+00 ; 3.382148e+00 ];

%-- Image #152:
omc_152 = [ NaN ; NaN ; NaN ];
Tc_152  = [ NaN ; NaN ; NaN ];
omc_error_152 = [ NaN ; NaN ; NaN ];
Tc_error_152  = [ NaN ; NaN ; NaN ];

%-- Image #153:
omc_153 = [ NaN ; NaN ; NaN ];
Tc_153  = [ NaN ; NaN ; NaN ];
omc_error_153 = [ NaN ; NaN ; NaN ];
Tc_error_153  = [ NaN ; NaN ; NaN ];

%-- Image #154:
omc_154 = [ NaN ; NaN ; NaN ];
Tc_154  = [ NaN ; NaN ; NaN ];
omc_error_154 = [ NaN ; NaN ; NaN ];
Tc_error_154  = [ NaN ; NaN ; NaN ];

%-- Image #155:
omc_155 = [ NaN ; NaN ; NaN ];
Tc_155  = [ NaN ; NaN ; NaN ];
omc_error_155 = [ NaN ; NaN ; NaN ];
Tc_error_155  = [ NaN ; NaN ; NaN ];

%-- Image #156:
omc_156 = [ NaN ; NaN ; NaN ];
Tc_156  = [ NaN ; NaN ; NaN ];
omc_error_156 = [ NaN ; NaN ; NaN ];
Tc_error_156  = [ NaN ; NaN ; NaN ];

%-- Image #157:
omc_157 = [ NaN ; NaN ; NaN ];
Tc_157  = [ NaN ; NaN ; NaN ];
omc_error_157 = [ NaN ; NaN ; NaN ];
Tc_error_157  = [ NaN ; NaN ; NaN ];

%-- Image #158:
omc_158 = [ NaN ; NaN ; NaN ];
Tc_158  = [ NaN ; NaN ; NaN ];
omc_error_158 = [ NaN ; NaN ; NaN ];
Tc_error_158  = [ NaN ; NaN ; NaN ];

%-- Image #159:
omc_159 = [ NaN ; NaN ; NaN ];
Tc_159  = [ NaN ; NaN ; NaN ];
omc_error_159 = [ NaN ; NaN ; NaN ];
Tc_error_159  = [ NaN ; NaN ; NaN ];

%-- Image #160:
omc_160 = [ NaN ; NaN ; NaN ];
Tc_160  = [ NaN ; NaN ; NaN ];
omc_error_160 = [ NaN ; NaN ; NaN ];
Tc_error_160  = [ NaN ; NaN ; NaN ];

%-- Image #161:
omc_161 = [ -1.605461e+00 ; -1.820924e+00 ; 8.421200e-01 ];
Tc_161  = [ -1.026009e+02 ; -2.082508e+02 ; 1.419886e+03 ];
omc_error_161 = [ 3.500315e-03 ; 2.912754e-03 ; 4.522267e-03 ];
Tc_error_161  = [ 5.896332e+00 ; 4.465974e+00 ; 3.382672e+00 ];

%-- Image #162:
omc_162 = [ NaN ; NaN ; NaN ];
Tc_162  = [ NaN ; NaN ; NaN ];
omc_error_162 = [ NaN ; NaN ; NaN ];
Tc_error_162  = [ NaN ; NaN ; NaN ];

%-- Image #163:
omc_163 = [ NaN ; NaN ; NaN ];
Tc_163  = [ NaN ; NaN ; NaN ];
omc_error_163 = [ NaN ; NaN ; NaN ];
Tc_error_163  = [ NaN ; NaN ; NaN ];

%-- Image #164:
omc_164 = [ NaN ; NaN ; NaN ];
Tc_164  = [ NaN ; NaN ; NaN ];
omc_error_164 = [ NaN ; NaN ; NaN ];
Tc_error_164  = [ NaN ; NaN ; NaN ];

%-- Image #165:
omc_165 = [ NaN ; NaN ; NaN ];
Tc_165  = [ NaN ; NaN ; NaN ];
omc_error_165 = [ NaN ; NaN ; NaN ];
Tc_error_165  = [ NaN ; NaN ; NaN ];

%-- Image #166:
omc_166 = [ NaN ; NaN ; NaN ];
Tc_166  = [ NaN ; NaN ; NaN ];
omc_error_166 = [ NaN ; NaN ; NaN ];
Tc_error_166  = [ NaN ; NaN ; NaN ];

%-- Image #167:
omc_167 = [ NaN ; NaN ; NaN ];
Tc_167  = [ NaN ; NaN ; NaN ];
omc_error_167 = [ NaN ; NaN ; NaN ];
Tc_error_167  = [ NaN ; NaN ; NaN ];

%-- Image #168:
omc_168 = [ NaN ; NaN ; NaN ];
Tc_168  = [ NaN ; NaN ; NaN ];
omc_error_168 = [ NaN ; NaN ; NaN ];
Tc_error_168  = [ NaN ; NaN ; NaN ];

%-- Image #169:
omc_169 = [ NaN ; NaN ; NaN ];
Tc_169  = [ NaN ; NaN ; NaN ];
omc_error_169 = [ NaN ; NaN ; NaN ];
Tc_error_169  = [ NaN ; NaN ; NaN ];

%-- Image #170:
omc_170 = [ NaN ; NaN ; NaN ];
Tc_170  = [ NaN ; NaN ; NaN ];
omc_error_170 = [ NaN ; NaN ; NaN ];
Tc_error_170  = [ NaN ; NaN ; NaN ];

%-- Image #171:
omc_171 = [ -1.820365e+00 ; -2.190443e+00 ; 4.478280e-01 ];
Tc_171  = [ -1.477155e+02 ; -2.272101e+02 ; 1.329585e+03 ];
omc_error_171 = [ 3.194420e-03 ; 3.051000e-03 ; 5.659117e-03 ];
Tc_error_171  = [ 5.517652e+00 ; 4.181914e+00 ; 3.477938e+00 ];

